package com.xy.utils;

import com.xy.entity.SysDictRedis;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * 字典工具类
 */
public class SysDictUtils {

    /**
     * 字典redis前缀
     */
    public static final String SYS_DICT_REDIS_PREFIX = "sys_dict";

    public static String getKey(String key) {
        return String.format("%s:%s", SYS_DICT_REDIS_PREFIX, key);
    }

    private static RedisService<SysDictRedis> getRedisService() {
        return SpringBeanUtils.getBean(RedisService.class);
    }

    /**
     * 父code获取所有子级列表
     *
     * @param paterCode 父code
     * @return k=code v=子对象
     */
    public static Map<String, SysDictRedis> get(String paterCode) {
        return getRedisService().getMap(getKey(paterCode));
    }

    public static List<Map<String, SysDictRedis>> get(List<String> paterCodes) {
        List<Map<String, SysDictRedis>> list = new ArrayList<>(paterCodes.size());
        RedisService<SysDictRedis> redisService = getRedisService();
        paterCodes.forEach(code -> list.add(redisService.getMap(getKey(code))));

        return list;
    }

    /**
     * 父code和code获取对象
     *
     * @param paterCode 父code
     * @param code      code
     * @return 子对象
     */
    public static SysDictRedis get(String paterCode, String code) {
        return getRedisService().getMap(getKey(paterCode), code);
    }

    /**
     * 获取所有字典
     *
     * @return
     */
    public static List<Map<String, Map<String, SysDictRedis>>> all() {
        return getRedisService().likeMap(SYS_DICT_REDIS_PREFIX);
    }
}
